package com.tzld.piaoquan.longarticle.service.impl;

import com.alibaba.fastjson.JSON;
import com.google.common.collect.Lists;
import com.tzld.piaoquan.longarticle.common.enums.PublishGzhPushTypeEnum;
import com.tzld.piaoquan.longarticle.dao.mapper.PlanAccountMapper;
import com.tzld.piaoquan.longarticle.dao.mapper.PublishContentMapper;
import com.tzld.piaoquan.longarticle.dao.mapper.PublishMiniprogramMapper;
import com.tzld.piaoquan.longarticle.dao.mapper.RootSourceMapper;
import com.tzld.piaoquan.longarticle.model.dto.*;
import com.tzld.piaoquan.longarticle.model.bo.*;
import com.tzld.piaoquan.longarticle.model.po.*;
import com.tzld.piaoquan.longarticle.model.po.PlanAccount;
import com.tzld.piaoquan.longarticle.model.vo.*;
import com.tzld.piaoquan.longarticle.service.CoreService;
import com.tzld.piaoquan.longarticle.utils.DateUtil;
import com.tzld.piaoquan.longarticle.utils.LarkRobotUtil;
import com.tzld.piaoquan.longarticle.utils.TimeZoneUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.math.BigDecimal;
import java.time.LocalTime;
import java.util.*;
import java.util.stream.Collectors;

@Slf4j
@Service
public class CoreServiceImpl implements CoreService {

    @Autowired
    private PlanServiceImpl planService;

    @Autowired
    private SortServiceImpl sortService;

    @Autowired
    private ContentServiceImpl contentService;

    @Autowired
    private PublishServiceImpl publishService;

    @Autowired
    private KimiServiceImpl kimiService;

    @Autowired
    private CardServiceImpl cardService;

    @Autowired
    private CoverServiceImpl coverService;

    @Autowired
    private PlanAccountMapper planAccountMapper;

    @Autowired
    private PlanAccountServiceImpl planAccountService;

    @Autowired
    private PublishMiniprogramMapper publishMiniprogramMapper;

    @Autowired
    private PublishContentMapper publishContentMapper;

    @Autowired
    private RootSourceMapper rootSourceMapper;

    @Override
    public void initPlanAccount() {
        List<LongArticleSystemPlan> allLongArticleSystemPlans = planService.getAllLongArticleSystemPlan();
        for (LongArticleSystemPlan longArticleSystemPlan : allLongArticleSystemPlans) {
            if (longArticleSystemPlan.getPublishRate() == 1) {
                List<Integer> weeks = JSON.parseArray(longArticleSystemPlan.getPublishDate(), Integer.class);
                if (!weeks.contains(TimeZoneUtil.getTodayDayOfWeek(TimeZoneUtil.Timezone.china))) {
                    continue;
                }
            }
            //获取排序策略
            Map<String, String> sortStgMap = new HashMap<>();
            List<GzhArticleSortTaskParam> gzhArticleSortTask = longArticleSystemPlan.getGzhArticleSortTask();
            for (GzhArticleSortTaskParam gzhArticleSortTaskParam : gzhArticleSortTask) {
                String strategy = gzhArticleSortTaskParam.getStrategy();
                List<String> accountIds = gzhArticleSortTaskParam.getAccountIds();
                for (String accountId : accountIds) {
                    sortStgMap.put(accountId, strategy);
                }
            }
            //获取小程序策略
            Map<String, MiniprogramInsertTaskParam> miniStgMap = new HashMap<>();
            List<MiniprogramInsertTaskParam> miniprogramInsertTasks = longArticleSystemPlan.getMiniprogramInsertTasks();
            for (MiniprogramInsertTaskParam miniprogramInsertTaskParam : miniprogramInsertTasks) {
                List<String> accountIds = miniprogramInsertTaskParam.getAccountIds();
                for (String accountId : accountIds) {
                    miniStgMap.put(accountId, miniprogramInsertTaskParam);
                }
            }
            for (LongArticleSystemPlanAccount account : longArticleSystemPlan.getAccountList()) {
                PlanAccountExample example = new PlanAccountExample();
                example.createCriteria().andAccountIdEqualTo(account.getId()).andPlanIdEqualTo(longArticleSystemPlan.getId())
                        .andCreateTimeGreaterThan(DateUtil.getThatDayDate());
                long l = planAccountMapper.countByExample(example);
                if (l > 0) {
                    continue;
                }
                PlanAccount planAccount = new PlanAccount();
                String accountId = account.getId();
                planAccount.setPlanId(longArticleSystemPlan.getId());
                planAccount.setPlanName(longArticleSystemPlan.getName());
                planAccount.setAccountId(accountId);
                planAccount.setAccountName(account.getName());
                planAccount.setGhId(account.getGhId());
                planAccount.setPublishRate(longArticleSystemPlan.getPublishRate());
                planAccount.setPublishDate(longArticleSystemPlan.getPublishDate());
                planAccount.setPublishNum(longArticleSystemPlan.getPublishNum());
                planAccount.setPublishWindowStart(longArticleSystemPlan.getPublishWindowStart());
                planAccount.setPublishWindowEnd(longArticleSystemPlan.getPublishWindowEnd());
                planAccount.setPublishTimeInterval(longArticleSystemPlan.getPublishTimeInterval());
                planAccount.setPublishNum(longArticleSystemPlan.getPublishNum());
                planAccount.setPublishPreNum(longArticleSystemPlan.getPublishPerNum());
                planAccount.setPublishPreMinNum(longArticleSystemPlan.getPublishPerMinNum());
                planAccount.setPublishPushTime(longArticleSystemPlan.getPublishPushTime());
                planAccount.setPushType(longArticleSystemPlan.getPushType());
                planAccount.setMiniprogramInsertFlag(longArticleSystemPlan.getMiniprogramInsertFlag());
                MiniprogramInsertTaskParam miniprogramInsertTaskParam = miniStgMap.get(accountId);
                if (miniprogramInsertTaskParam != null) {
                    planAccount.setMiniprogramUseType(miniprogramInsertTaskParam.getMiniprogramUseType());
                    planAccount.setMiniStrategy(miniprogramInsertTaskParam.getStrategy());
                }
                if (sortStgMap.containsKey(accountId)) {
                    planAccount.setSortStrategy(sortStgMap.get(accountId));
                }
                planAccount.setPushType(longArticleSystemPlan.getPushType());
                planAccountMapper.insertSelective(planAccount);
            }
        }
    }

    @Override
    public void matchContent() {
        //查询状态为0的请求匹配
        PlanAccountExample example = new PlanAccountExample();
        example.createCriteria().andCreateTimeGreaterThan(DateUtil.getThatDayDate()).andMatchStatusEqualTo(0);
        List<PlanAccount> planAccounts = planAccountMapper.selectByExample(example);
        for (PlanAccount planAccount : planAccounts) {
            LongArticleSystemGetContentsParam param = new LongArticleSystemGetContentsParam();
            param.setAccountId(planAccount.getAccountId());
            param.setPlanId(planAccount.getPlanId());
            LongArticleSystemContentVO longArticleSystemContentVO = planService.getContentItemList(param);
            if (longArticleSystemContentVO == null) {
                continue;
            }
            //没有待匹配的文章  更新状态为1
            if (longArticleSystemContentVO.getTotalCount() == 0) {
                planAccountService.updateMatchStatus(1, planAccount.getId());
                continue;
            }
            for (ContentItemVO contentItemVO : longArticleSystemContentVO.getContentItemList()) {
                MatchVideo content = contentService.getContent(contentItemVO.getSourceId(), planAccount.getGhId());
                if (content != null) {
                    Integer contentStatus = content.getContentStatus();
                    if (contentStatus == 3 || contentStatus == 4) {
                        MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                        statusParam.setStatus(2);
                        statusParam.setPublishContentId(contentItemVO.getPublishContentId());
                        planService.updateMatchMiniprogramStatus(statusParam);
                        continue;
                    }
                    if (contentStatus == 99 || contentStatus == 97) {
                        MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                        statusParam.setStatus(3);
                        statusParam.setPublishContentId(contentItemVO.getPublishContentId());
                        if (contentStatus == 99) {
                            statusParam.setErrorMsg("匹配视频失败");
                        }
                        if (contentStatus == 97) {
                            statusParam.setErrorMsg("文章晋级或者退场");
                        }
                        planService.updateMatchMiniprogramStatus(statusParam);
                    }
                } else {
                    MiniprogramCardRequest request = new MiniprogramCardRequest();
                    request.setGhId(planAccount.getGhId());
                    request.setAccountName(planAccount.getAccountName());
                    request.setContent(contentItemVO.getContent());
                    request.setTitle(contentItemVO.getTitle());
                    //请求到新服务
                    request.setStrategy("strategy_v2");
                    request.setArticleId(contentItemVO.getSourceId());
                    request.setFlowPoolLevelTag(contentItemVO.getFlowPoolLevelTag());
                    contentService.matchMiniprogramVideo(request);
                }
            }
        }
    }

    private boolean effectiveTime(String startWindow, String endWindow, TimeZoneUtil.Timezone timezone) {
        if (!org.springframework.util.StringUtils.hasText(startWindow) || !org.springframework.util.StringUtils.hasText(endWindow)) {
            return true;
        }
        LocalTime currentTime = TimeZoneUtil
                .currentTime(Optional.ofNullable(timezone).orElse(TimeZoneUtil.Timezone.china));

        if (currentTime.isAfter(LocalTime.parse(startWindow)) && currentTime.isBefore(LocalTime.parse(endWindow))) {
            return true;
        }

        return false;
    }

    private boolean checkPlanAccount(PlanAccount planAccount) {
        boolean flag = true;
        // 固定日期
        if (planAccount.getPublishRate() == 1) {
            List<Integer> weeks = JSON.parseArray(planAccount.getPublishDate(), Integer.class);
            if (!weeks.contains(TimeZoneUtil.getTodayDayOfWeek(TimeZoneUtil.Timezone.china))) {
                planAccount.setStatus(2);
                planAccountMapper.updateByPrimaryKeySelective(planAccount);
                return false;
            }
        }
        // 指定时间
        if (StringUtils.isNotEmpty(planAccount.getPublishPushTime())) {
            LocalTime currentTime = TimeZoneUtil.currentTime(TimeZoneUtil.Timezone.china);
            LocalTime pushTime = LocalTime.parse(planAccount.getPublishPushTime());
            if (currentTime.isBefore(pushTime.minusMinutes(20))) {
                return false;
            }
            if (currentTime.isAfter(pushTime.plusMinutes(60))) {
                return false;
            }
        } else if (StringUtils.isNotEmpty(planAccount.getPublishWindowStart())
                && StringUtils.isNotEmpty(planAccount.getPublishWindowEnd())) {
            if (!effectiveTime(planAccount.getPublishWindowStart(), planAccount.getPublishWindowEnd(),
                    TimeZoneUtil.Timezone.china)) {
                return false;
            }
            if (planAccount.getPublishTimeInterval() != null) {
                // 找到该账号最近发布的内容，判断时间间隔
                PublishContentExample example = new PublishContentExample();
                example.createCriteria().andStatusIn(Arrays.asList(1, 2)).andCreateTimeGreaterThan(DateUtil.getThatDayDate());
                example.setOrderByClause("create_time desc");
                List<PublishContent> publishContents = publishContentMapper.selectByExample(example);
                if (!CollectionUtils.isEmpty(publishContents)) {
                    long time = System.currentTimeMillis() - publishContents.get(0).getCreateTime().getTime();
                    if (time < planAccount.getPublishTimeInterval() * 60 * 1000L) {
                        return false;
                    }
                }
            }
        }
        PublishContentExample example = new PublishContentExample();
        example.createCriteria().andStatusIn(Arrays.asList(1, 2)).andCreateTimeGreaterThan(DateUtil.getThatDayDate());
        long sendCount = publishContentMapper.countByExample(example);
        Integer publishNum = planAccount.getPublishNum();
        if (publishNum == null || publishNum == 0) {
            return false;
        }
        if (sendCount >= publishNum) {
            return false;
        }
        if (planAccount.getRetryCount() >= 3) {
            planAccount.setStatus(3);
            planAccountMapper.updateByPrimaryKeySelective(planAccount);
            LarkRobotUtil.sendMessage("计划发布失败3次，请查看 账号计划id为" + planAccount.getPlanId());
            return false;
        }

        return flag;
    }


    @Override
    public void core() {
        PlanAccountExample example = new PlanAccountExample();
        example.createCriteria().andCreateTimeGreaterThan(DateUtil.getThatDayDate()).andStatusEqualTo(0);
        List<PlanAccount> planAccounts = planAccountMapper.selectByExample(example);
        for (PlanAccount planAccount : planAccounts) {
            boolean flag = checkPlanAccount(planAccount);
            if (!flag) {
                continue;
            }
            ArticleSortRequest articleSortRequest = new ArticleSortRequest();
            articleSortRequest.setAccountId(planAccount.getAccountId());
            articleSortRequest.setAccountName(planAccount.getAccountName());
            articleSortRequest.setGhId(planAccount.getGhId());
            articleSortRequest.setStrategy("ArticleRankRandom");
            //articleSortRequest.setStrategy(planAccount.getSortStrategy());
            if (Objects.equals(planAccount.getPushType(), PublishGzhPushTypeEnum.manual_push.getVal())) {
                PublishContentExample publishContentExample = new PublishContentExample();
                publishContentExample.createCriteria().andStatusIn(Arrays.asList(1, 2)).andCreateTimeGreaterThan(DateUtil.getThatDayDate());
                long sendCount = publishContentMapper.countByExample(publishContentExample);
                if (planAccount.getPublishPreNum() <= (planAccount.getPublishNum() - sendCount)) {
                    articleSortRequest.setPublishNum(planAccount.getPublishPreNum());
                } else {
                    articleSortRequest.setPublishNum((int) (planAccount.getPublishNum() - sendCount));
                }
            }
            if (Objects.equals(PublishGzhPushTypeEnum.auto_group_publish.getVal(), planAccount.getPushType())) {
                articleSortRequest.setPublishNum(planAccount.getPublishNum());
            }
            articleSortRequest.setPlanId(planAccount.getPlanId());
            articleSortRequest.setPushType(planAccount.getPushType());

            ArticleSortResponse articleSortResponse = sortService.publishArticleSort(articleSortRequest);
            if (articleSortResponse == null || articleSortResponse.getData() == null) {
                continue;
            }
            if (CollectionUtils.isEmpty(articleSortResponse.getData().getRank_list())) {
                planAccount.setRetryCount(planAccount.getRetryCount() + 1);
                planAccountMapper.updateByPrimaryKeySelective(planAccount);
                continue;
            }
            ArticleSortResponseData data = articleSortResponse.getData();
            if (!CollectionUtils.isEmpty(data.getFilter_list())) {
                List<FilterSortContentParam> list = new ArrayList<>();
                for (PublishArticleData publishArticleData : data.getFilter_list()) {
                    FilterSortContentParam param = new FilterSortContentParam();
                    param.setFilterReason(publishArticleData.getFilterReason());
                    param.setPublishContentId(publishArticleData.getId());
                    list.add(param);
                }
                FilterSortParam param = new FilterSortParam();
                param.setFilterSortContentList(list);
                planService.filterSortContents(param);
            }
            List<LongArticleSystemPushContentParam> pushContentList = new ArrayList<>();
            //排序结束
            List<PublishArticleData> rankList = data.getRank_list();
            List<Long> sendIds = new ArrayList<>();
            for (PublishArticleData publishArticleData : rankList) {
                LongArticleSystemPushContentParam contentParam = new LongArticleSystemPushContentParam();
                String publishContentId = publishArticleData.getId();
                PublishContent publishContent = new PublishContent();
                publishContent.setPlanAccountId(planAccount.getId());
                publishContent.setPublishContentId(publishArticleData.getId());
                publishContent.setSourceId(publishArticleData.getSourceId());
                publishContent.setScore(publishArticleData.getScore());
                publishContent.setContentPoolType(publishArticleData.getContentPoolType());
                publishContentMapper.insertSelective(publishContent);
                sendIds.add(publishContent.getId());
                //获取小程序
                List<CrawlerVideo> contentVideos =
                        contentService.getContentVideo(publishArticleData.getSourceId(), publishArticleData.getContentPoolType(), planAccount.getGhId());
                List<VideoDetail> videoDetails = new ArrayList<>();
                //发布小程序
                for (CrawlerVideo crawlerVideo : contentVideos) {
                    String videoOssPath = crawlerVideo.getVideoOssPath();
                    String platform = crawlerVideo.getPlatform();
                    String userId = crawlerVideo.getUserId();
                    String traceId = crawlerVideo.getTraceId();
                    String kimiTitle;
                    LongArticlesText kimiText = kimiService.getKimiText(crawlerVideo.getContentId());
                    if (kimiText != null && StringUtils.isNotEmpty(kimiText.getKimiTitle())) {
                        kimiTitle = kimiText.getKimiTitle();
                    } else {
                        kimiTitle = crawlerVideo.getVideoTitle();
                    }
                    VideoDetail publish = publishService.publish(videoOssPath, userId, kimiTitle, platform, traceId);
                    if (publish == null) {
                        continue;
                    }
                    videoDetails.add(publish);
                }
                if (videoDetails.size() < 2) {
                    MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                    statusParam.setStatus(3);
                    statusParam.setPublishContentId(publishContentId);
                    statusParam.setErrorMsg("小程序视频数量不足");
                    planService.updateMatchMiniprogramStatus(statusParam);

                    PublishContent update = new PublishContent();
                    update.setId(publishContent.getId());
                    update.setStatus(3);
                    update.setReason("小程序数量不足");
                    publishContentMapper.updateByPrimaryKeySelective(update);
                    continue;
                }
                String ghId = planAccount.getGhId();
                Long planAccountId = planAccount.getId();
                List<PublishMiniprogram> cardList = cardService.generateCards(planAccountId, ghId, videoDetails, planAccount.getMiniprogramUseType(), publishContentId);
                if (CollectionUtils.isEmpty(cardList) && cardList.size() < 2) {
                    continue;
                }
                List<PublishMiniprogramParam> publishCardList = new ArrayList<>();
                for (PublishMiniprogram publishMiniprogram : cardList) {
                    String videoCover = publishMiniprogram.getVideoCover();
                    String wxUrl = coverService.pushCover(videoCover, publishMiniprogram.getPublishContentId());
                    if (StringUtils.isEmpty(wxUrl)) {
                        continue;
                    }
                    PublishMiniprogramParam param = new PublishMiniprogramParam();
                    param.setProgramId(publishMiniprogram.getAppId());
                    param.setProgramName(publishMiniprogram.getAppName());
                    param.setProgramAvatar(publishMiniprogram.getAvatar());
                    param.setMini_id(Integer.valueOf(publishMiniprogram.getMiniId()));
                    param.setMiniprogramUseType(publishMiniprogram.getMiniProgramType());
                    String videoTitle = publishMiniprogram.getVideoTitle();
                    if (org.springframework.util.StringUtils.hasText(videoTitle)) {
                        videoTitle = videoTitle.replace("\"", "");
                        if (videoTitle.length() > 32) {
                            videoTitle = videoTitle.substring(0, 32);
                        }
                        param.setProductionName(videoTitle);
                    }
                    param.setProductionCover(wxUrl);
                    param.setProductionPath(publishMiniprogram.getProductionPath());
                    param.setRootShareId(publishMiniprogram.getRootShareId());
                    param.setSource(publishMiniprogram.getSource());
                    param.setVideoUrl(publishMiniprogram.getVideoPath());
                    param.setParagraphPosition(BigDecimal.valueOf(publishMiniprogram.getIndex() * 0.25));
                    if (publishMiniprogram.getIndex() == 1) {
                        param.setParagraphPosition(BigDecimal.valueOf(0.01));
                    }
                    param.setTraceId(publishMiniprogram.getTraceId());
                    publishCardList.add(param);
                    publishMiniprogram.setContentId(publishContent.getId());
                    RootSource rootSource = new RootSource();
                    rootSource.setAccountName(planAccount.getAccountName());
                    rootSource.setRootSourceId(publishMiniprogram.getRootSourceId());
                    rootSource.setGhId(planAccount.getGhId());
                    rootSource.setRequestTime(Integer.valueOf(String.valueOf(System.currentTimeMillis() / 1000)));
                    rootSource.setTraceId(publishMiniprogram.getTraceId());
                    rootSource.setPushType(planAccount.getPushType());
                    rootSource.setVideoId(publishMiniprogram.getVideoId());
                    rootSource.setContentId(publishArticleData.getSourceId());
                    rootSourceMapper.insertSelective(rootSource);
                    publishMiniprogramMapper.insertSelective(publishMiniprogram);
                }

                if (publishCardList.size() < 2) {
                    MatchMiniprogramStatusParam statusParam = new MatchMiniprogramStatusParam();
                    statusParam.setStatus(3);
                    statusParam.setPublishContentId(publishContentId);
                    statusParam.setErrorMsg("小程序视频数量不足");
                    planService.updateMatchMiniprogramStatus(statusParam);

                    PublishContent update = new PublishContent();
                    update.setId(publishContent.getId());
                    update.setStatus(3);
                    update.setReason("小程序数量不足");
                    publishContentMapper.updateByPrimaryKeySelective(update);
                    continue;
                }
                contentParam.setPublishContentId(publishContentId);
                contentParam.setMiniprogramCardList(publishCardList);
                pushContentList.add(contentParam);
            }
            LongArticleSystemCreatePushTaskParam gzhPushParam = new LongArticleSystemCreatePushTaskParam();
            gzhPushParam.setPlanId(planAccount.getPlanId());
            gzhPushParam.setAccountId(planAccount.getAccountId());
            gzhPushParam.setPushType(planAccount.getPushType());
            gzhPushParam.setPushScheduleTimestamp(System.currentTimeMillis());
            if (StringUtils.isNotEmpty(planAccount.getPublishPushTime())) {
                String dateTimeStr = TimeZoneUtil.todayYMD(TimeZoneUtil.Timezone.china) + " " + planAccount.getPublishPushTime();
                gzhPushParam.setPushScheduleTimestamp(TimeZoneUtil.getDateStrTimestamp(dateTimeStr, "yyyy-MM-dd HH:mm:ss", TimeZoneUtil.Timezone.china));
            } else {
                gzhPushParam.setPushScheduleTimestamp(System.currentTimeMillis());
            }
            gzhPushParam.setPushContentList(pushContentList);
            if (Objects.equals(planAccount.getPushType(), PublishGzhPushTypeEnum.auto_group_publish.getVal())
                    && pushContentList.size() < planAccount.getPublishPreMinNum()) {
                continue;
            }
            String pushId = planService.createPushTask(gzhPushParam);
            System.out.println(pushId);
            if (StringUtils.isNotEmpty(pushId)) {
                for (Long id : sendIds) {
                    PublishContent publishContent = publishContentMapper.selectByPrimaryKey(id);
                    if (publishContent == null || publishContent.getStatus() != 0) {
                        continue;
                    }
                    PublishContent update = new PublishContent();
                    update.setId(id);
                    update.setPushId(pushId);
                    update.setStatus(1);
                    publishContentMapper.updateByPrimaryKeySelective(update);
                }
            }
        }
    }

    @Override
    public void getPushStatus() {
        PublishContentExample example = new PublishContentExample();
        example.createCriteria().andStatusEqualTo(1).andPushIdIsNotNull();
        List<PublishContent> publishContents = publishContentMapper.selectByExample(example);
        Set<String> collect = publishContents.stream().map(PublishContent::getPushId).collect(Collectors.toSet());
        for (String pushId : collect) {
            PushStatusParam param = new PushStatusParam();
            param.setPushId(pushId);
            PushStatusVO pushStatusVO = planService.queryPushStatus(param);
            if (pushStatusVO == null) {
                continue;
            }
            int updateStatus = 0;
            //推送失败  重新推送
            if (pushStatusVO.getPushStatus() == 3) {
                updateStatus = 3;
            }
            //推送成功
            if (pushStatusVO.getPushStatus() == 2) {
                //发表失败
                if (pushStatusVO.getPublishStatus() == 3) {
                    updateStatus = 3;
                }
                //发表成功
                if (pushStatusVO.getPublishStatus() == 2) {
                    updateStatus = 2;
                }
            }
            //更新状态  2成功  3失败
            if (updateStatus != 0) {
                PublishContentExample publishContentExample = new PublishContentExample();
                publishContentExample.createCriteria().andPushIdEqualTo(pushId);
                PublishContent update = new PublishContent();
                update.setStatus(updateStatus);
                publishContentMapper.updateByExampleSelective(update, publishContentExample);

                List<PublishContent> publishContentList = publishContentMapper.selectByExample(publishContentExample);
                if (!CollectionUtils.isEmpty(publishContentList)) {
                    Long planAccountId = publishContentList.get(0).getPlanAccountId();
                    if (planAccountId == null) {
                        continue;
                    }
                    PlanAccount planAccount = planAccountMapper.selectByPrimaryKey(planAccountId);
                    if (Objects.equals(planAccount.getPushType(), PublishGzhPushTypeEnum.auto_group_publish.getVal())) {
                        if (updateStatus == 2) {
                            planAccount.setStatus(2);
                            planAccountMapper.updateByPrimaryKeySelective(planAccount);
                        }
                        if (updateStatus == 3) {
                            planAccount.setRetryCount(planAccount.getRetryCount() + 1);
                            planAccountMapper.updateByPrimaryKeySelective(planAccount);
                        }
                    }
                }
            }
        }
    }
}
